#!/usr/bin/perl -I/usr/sausalito/perl
# $Id: import_yumconfs.pl, v1.0.0-1 Tue 11 Aug 2009 08:21:11 AM CEST mstauber Exp $
# Copyright 2006-2009 Solarspeed Ltd. All rights reserved.

# Constructor that parses the Aventurin{e} YUM repository files to see which repos 
# are currently enabled. That info is then stored into CODB for GUI usage.

# Debugging switch:
$DEBUG = "0";

$whatami = "constructor";

# Location of Repository files:
$repo_base_cf = "/etc/yum.repos.d/Aventurin-Base.repo";
$repo_ost_cf = "/etc/yum.repos.d/Aventurin-OS-Templates.repo";
$repo_osupdates_cf = "/etc/yum.repos.d/Aventurin-OS-Updates.repo";
#$repo_slupdates_cf = "/etc/yum.repos.d/Aventurin-OS-Updates.repo";
#$repo_vzupdates_cf = "/etc/yum.repos.d/Aventurin-OS-Updates.repo";

#
#### No configureable options below!
#

@repo_files = ("$repo_base_cf", "$repo_ost_cf", "$repo_osupdates_cf");

use CCE;
use Data::Dumper;

my $cce = new CCE;

if ($whatami eq "handler") {
    $cce->connectfd();
}
else {
    $cce->connectuds();
}

# Loop through the config files:
foreach $config (@repo_files) {

    # Config file present?
    if (-f $config) {

	# Read, parse and hash pam_abl.conf:
        &ini_read;

        # Shove ouput into CCE:
        &feedthemonster;
    }
    else {
	# Ok, we have a problem: No pam_abl.conf found.
	# So we just weep silently and exit. 
	$cce->bye('FAIL', "$config not found!");
	exit(1);
    }
}

$cce->bye('SUCCESS');
exit(0);

# Read and parse pam_abl.conf:
sub ini_read {
    open (F, $config) || die "Could not open $config: $!";

    while ($line = <F>) {
        chomp($line);
        next if $line =~ /^\s*$/;               	# skip blank lines
        next if $line =~ /^\#*$/;               	# skip comment lines
        if ($line =~ /^([A-Za-z_\.]\w*)/) {		
	    $line =~s/\s//g; 				# Remove spaces
	    $line =~s/#(.*)$//g; 			# Remove trailing comments in lines
	    $line =~s/\"//g; 				# Remove double quotation marks

            @row = split (/=/, $line);			# Split row at the equal sign. Unfortunately if there are more than one
    	    $CONFIG{$row[0]} = $row[1];			# Build our config Hash
        }
    }
    close(F);

    # At this point we have all switches from pam_abl.conf cleanly in a hash, split in key / value pairs.
    # To read how "user_rule" is set we query $CONFIG{'user_rule'} for example. 

    # For debugging only:
    if ($DEBUG == "1") {
	print "DEBUG: $config " . $CONFIG{'enabled'} . "\n";
    }

}

sub feedthemonster {
    @oids = $cce->find('System');
    if ($#oids < 0) {
        # Object not yet in CCE. Skipping for now and operating with schema defaults.
	$cce->bye('SUCCESS');
	exit(0);
    }
    else {
        # Object already present in CCE. Updating it.
        ($sys_oid) = $cce->find('System');
        ($ok, $sys) = $cce->get($sys_oid);

	if ($config eq $repo_base_cf) {
	    $repo = "repo_base";
	}
	elsif ($config eq $repo_ost_cf) {
	    $repo = "repo_ost";
	}
	elsif ($config eq $repo_osupdates_cf) {
	    $repo = "repo_osupdates";
	}

    	# For debugging only:
    	if ($DEBUG == "1") {
		print "Repo: $repo - " . $CONFIG{"enabled"} .  "\n";
	}
	
        ($ok) = $cce->set($sys_oid, 'yum',{
	    $repo => $CONFIG{"enabled"}  
        });
    }
}

$cce->bye('SUCCESS');
exit(0);

